Learn R Programming

rrcovNA (version 0.4-8)

CovNA-class: Class "CovNA" -- a base class for estimates of multivariate location and scatter for incomplete data

Description

The class CovNA represents an estimate of the multivariate location and scatter of a data set. The objects of class CovNA contain the classical estimates and serve as base for deriving other estimates, i.e. different types of robust estimates.

Arguments

Objects from the Class

Objects can be created by calls of the form new("CovNA", ...), but the usual way of creating CovNA objects is a call to the function CovNA which serves as a constructor.

Slots

call:
Object of class "language"
cov:
covariance matrix
center:
location
n.obs:
number of observations used for the computation of the estimates
mah:
mahalanobis distances
det:
determinant
flag:
flags (FALSE if suspected an outlier)
method:
a character string describing the method used to compute the estimate: "Classic"
singularity:
a list with singularity information for the covariance matrix (or NULL of not singular)
X:
data

Extends

Class "Cov", directly.

Methods

getDistance
signature(obj = "CovNA"): distances
getFlag
signature(obj = "CovNA"): Flags observations as outliers if the corresponding mahalanobis distance is larger then qchisq(prob, p) where prob defaults to 0.975.
summary
signature(object = "CovNA"): calculate summary information

References

Todorov V & Filzmoser P (2009), An Object Oriented Framework for Robust Multivariate Analysis. Journal of Statistical Software, 32(3), 1--47. URL http://www.jstatsoft.org/v32/i03/.

Examples

Run this code
showClass("CovNA")

Run the code above in your browser using DataLab