Learn R Programming

rrcovNA (version 0.4-8)

CovNAClassic-class: Class "CovNAClassic" - classical estimates of multivariate location and scatter for incomplete data (EM algorithm)

Description

The class CovNAClassic represents an estimate of the multivariate location and scatter of an incomplete data set. The class CovNAClassic objects contain the classical estimates.

Arguments

Objects from the Class

Objects can be created by calls of the form new("CovNAClassic", ...), but the usual way of creating CovNAClassic objects is a call to the function CovNAClassic which serves as a constructor.

Slots

call:
Object of class "language"
cov:
covariance matrix
center:
location
n.obs:
number of observations used for the computation of the estimates
mah:
mahalanobis distances
method:
a character string describing the method used to compute the estimate: "Classic"
singularity:
a list with singularity information for the ocvariance matrix (or NULL of not singular)
X:
data

Methods

plot
signature(x = "CovNAClassic"): plot the object

References

Todorov V & Filzmoser P (2009), An Object Oriented Framework for Robust Multivariate Analysis. Journal of Statistical Software, 32(3), 1--47. URL http://www.jstatsoft.org/v32/i03/.

Examples

Run this code
data(bush10)
cv <- CovNAClassic(bush10)
cv
summary(cv)

Run the code above in your browser using DataLab