CovNAMcd(x, alpha = 1/2, nsamp = 500, seed = NULL, trace = FALSE,
use.correction = TRUE, impMeth = c("norm" , "seq", "rseq"), control)alpha*n
observations are used for computing the determinant. Allowed values
are between 0.5 and 1 and the default is 0.5."best"
or "exact". Default is nsamp = 500. For
nsamp="best" exhaustive enumeration is done, as long as the
number of trials does not exceed 5000. For "exact",
exhaustive enumeration will be attempted however many samples are
needed. In this case a warning message will be displayed saying
that the computation can take a very long time.seed = NULLtrace = FALSEuse.correction=TRUECovControlMcd-class
containing estimation options - same as these provided in the function
specification. If the control object is supplied, the parameters from it
will be used. If parameters are passed also in the invocation statement, they will
override the corresponding elements of the control object.CovNAMcd-class which is a subclass of the
virtual class CovNARobust-class.
CovMcd-class containing the estimates.
The implementation of the function is similar to the existing R function
covMcd() which returns an S3 object.
The MCD method looks for the $h (> n/2)$
observations (out of $n$) whose classical
covariance matrix has the lowest possible determinant. The raw MCD
estimate of location is then the average of these $h$ points,
whereas the raw MCD estimate of scatter is their covariance matrix,
multiplied by a consistency factor and a finite sample correction factor
(to make it consistent at the normal model and unbiased at small samples).
Both rescaling factors are returned also in the vector raw.cnp2
of length 2. Based on these raw MCD estimates, a reweighting step is performed
which increases the finite-sample efficiency considerably - see Pison et al. (2002).
The rescaling factors for the reweighted estimates are returned in the
vector cnp2 of length 2. Details for the computation of the finite
sample correction factors can be found in Pison et al. (2002).
The finite sample corrections can be suppressed by setting use.correction=FALSE.
The implementation in rrcov uses the Fast MCD algorithm of Rousseeuw and Van Driessen (1999)
to approximate the minimum covariance determinant estimator.
Todorov V & Filzmoser P (2009), An Object Oriented Framework for Robust Multivariate Analysis. Journal of Statistical Software, 32(3), 1--47. URL http://www.jstatsoft.org/v32/i03/.
data(bush10)
mcd <- CovNAMcd(bush10)
mcd
summary(mcd)
plot(mcd)
plot(mcd, which="pairs")
plot(mcd, which="xydistance")
plot(mcd, which="xyqqchi2")
Run the code above in your browser using DataLab