CovNAOgk(x, niter = 2, beta = 0.9, impMeth = c("norm" , "seq", "rseq"), control)CovControlOgk-class
containing estimation options - same as these provided in the function
specification. If the control object is supplied, the parameters from it
will be used. If parameters are passed also in the invocation statement, they will
override the corresponding elements of the control object. The control
object contains also functions for computing the robust univariate location
and dispersion estimate mrob and for computing the robust estimate
of the covariance between two random variables vrob. CovNAOgk-class which is a subclass of the
virtual class CovNARobust-class.
vrob of the control object
CovControlOgk. Similarly, the function for computing the robust
univariate location and dispersion used is the tau scale defined
in Yohai and Zamar (1998) but it can be redefined in the control object. The estimates obtained by the OGK method, similarly as in CovMcd are returned
as 'raw' estimates. To improve the estimates a reweighting step is performed using
the coverage parameter beta and these reweighted estimates are returned as
'final' estimates.
Gnanadesikan, R. and John R. Kettenring (1972) Robust estimates, residuals, and outlier detection with multiresponse data. Biometrics 28, 81--124.
Todorov V & Filzmoser P (2009), An Object Oriented Framework for Robust Multivariate Analysis. Journal of Statistical Software, 32(3), 1--47. URL http://www.jstatsoft.org/v32/i03/.
CovNAMcd data(bush10)
CovNAOgk(bush10)
## the following three statements are equivalent
c1 <- CovNAOgk(bush10, niter=1)
c2 <- CovNAOgk(bush10, control = CovControlOgk(niter=1))
## direct specification overrides control one:
c3 <- CovNAOgk(bush10, beta=0.95,
control = CovControlOgk(beta=0.99))
c1
Run the code above in your browser using DataLab