Draws missing elements of a data matrix under the multivariate normal
model and a user-supplied parameter
Usage
impNorm(x)
Arguments
x
the original incomplete data matrix.
Value
a matrix of the same form as x, but with all missing values filled in
with simulated values drawn from their predictive distribution given
the observed data and the specified parameter.
Details
This function simply uses imp.norm from package norm.